@@ -1,9 +1,13 @@
-# $Id: Line.pm,v 1.21 2001/07/27 16:27:28 rcaputo Exp $
+# $Id: Line.pm,v 1.23 2003/07/03 16:34:57 rcaputo Exp $
 
 package POE::Filter::Line;
 
 use strict;
-use Carp;
+
+use vars qw($VERSION);
+$VERSION = (qw($Revision: 1.23 $ ))[1];
+
+use Carp qw(carp croak);
 
 sub DEBUG () { 0 }
 
@@ -33,7 +37,7 @@ sub new {
   # Literal newline for both incoming and outgoing.  Every other known
   # parameter conflicts with this one.
   if (defined $params{Literal}) {
-    croak "Literal must be defined and have a nonzero length"
+    croak "A defined Literal must have a nonzero length"
       unless defined($params{Literal}) and length($params{Literal});
     $input_regexp   = quotemeta $params{Literal};
     $output_literal = $params{Literal};
