@@ -1,11 +1,26 @@
 #!/usr/bin/perl
-# $Id: Makefile-5005.pm,v 1.28 2003/05/02 12:55:23 rcaputo Exp $
+# $Id: Makefile-5005.pm,v 1.32 2003/08/31 02:07:50 rcaputo Exp $
 
 use strict;
 
 use lib qw(./lib);
 use ExtUtils::MakeMaker;
 
+# Switch to default behavior if STDIN isn't a tty.
+unless (-t STDIN) {
+  warn(
+    "\n",
+    "======================================================================\n",
+    "\n",
+    "Standard input is not a terminal/console.  Reverting to --default\n",
+    "behavior to avoid the prompts.\n",
+    "\n",
+    "======================================================================\n",
+    "\n",
+  );
+  push @ARGV, "--default";
+}
+
 eval "require ExtUtils::AutoInstall";
 if ($@) {
   warn( "\n",
@@ -148,8 +163,12 @@ WriteMakefile
                     'tee ./$(DISTNAME)-$(VERSION)/CHANGES > ./CHANGES'
                   ),
     },
+    test           => { TESTS => 't/*/*.t t/*.t' },
 
     PMLIBDIRS      => [ 'POE' ],
+    clean => {
+        FILES => 'poe_report.xml test-output.err coverage.report',
+    }
   );
 
 1;
